@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: parsers
 version: 0.12.3
-id: parsers-0.12.3-39fdea4c999d2dce5f1305b594de4161
-key: parse_CtATL5vXuTUDeN4kd0Ra9W
+id: parsers-0.12.3-249c3658e44c9e939031fdd5e1ad8519
+key: parse_Iz7m1NhGKbt9bMe2QoxPWl
 license: BSD3
 copyright: Copyright (C) 2010-2013 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,18 +27,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/parsers-0.12.3
-hs-libraries: HSparsers-0.12.3-CtATL5vXuTUDeN4kd0Ra9W
+hs-libraries: HSparsers-0.12.3-Iz7m1NhGKbt9bMe2QoxPWl
 depends:
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
-    charset-0.3.7.1-07fa1295548c21364abbf3188fa2df38
+    charset-0.3.7.1-eb9c9b19f9448bfb51c91765226aa73d
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
-    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
 haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
 haddock-html: /usr/share/doc/haskell-parsers/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
